@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: loader.c,v 1.1 2005/01/02 22:16:15 chpe Exp $
+ *  $Id: loader.c,v 1.1.2.1 2005/03/31 20:55:17 jframeau Exp $
  */
 
 #include "config.h"
@@ -33,7 +33,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyPythonExtension")
+	LOG ("Registering EphyPythonExtension");
 
 	ephy_python_extension_register_type (module);
 
